.. CONTRIBUTORS.rst
.. ================
..
.. Copying
.. -------
..
.. Copyright (c) 2020 none authors and contributors.
..
.. This file is part of the *none* project.
..
.. None is a free software project. You can redistribute it and/or
.. modify it following the terms of the MIT License.
..
.. This software project is distributed *as is*, WITHOUT WARRANTY OF ANY
.. KIND; including but not limited to the WARRANTIES OF MERCHANTABILITY,
.. FITNESS FOR A PARTICULAR PURPOSE and NONINFRINGEMENT.
..
.. You should have received a copy of the MIT License along with
.. *none*. If not, see <http://opensource.org/licenses/MIT>.

Contribution Agreement
======================

The purpose of this document is to clarify the intellectual property license
granted with Contribution from any person or entity.

By adding your name in below section *List of Contributors*, you accept and
agree to the following terms and conditions for you (further named Contributor)
present and future Contributions Submitted.

The below stated terms was last updated on August 25th, 2020.


.. contents:: In this page
  :depth: 3


Definitions
-----------

Contributor
    Shall mean the copyright owner or legal entity authorized by the copyright
    owner that is making the Agreement.

Contribution
    Shall mean the code, documentation or other original works of authorship
    that is intentionally Submitted by Contributor for inclusion into the
    project.

Submit
    Shall mean any form of electronic, verbal, or written communication sent to
    the project including but not limited to communication on electronic mailing
    lists, source code control systems and issue tracking systems that are
    managed by the project members.


Terms of agreement
------------------

The Submitter agrees by adding his or her name within the section below named
*Contributors* and Submitting the resulting modified document to the canonical
shared repository location for this software project, he or she is signing a
contract electronically. The Submitter becomes a Contributor after:

1. he or she signs this document by adding their name beneath the
   *Contributors* section below;
2. the resulting document is accepted into the canonical version
   control repository.


Licensing and copyright holding
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

The *none* project is released under the licensing terms of the MIT License
stated in the ``LICENSE.rst`` file.

Contributor formally license any Contribution Submitted to the project under the
same licensing terms. At the same time, Contributor shall also sign the file
``AUTHORS.rst``, remains copyright holder of the Contributions and is not asked
to transfer the copyright to any person or entity.


Representations, Warranty and Indemnification
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Contributor represents and warrants that Submitted code does not violate the
rights of any person or entity, and that Contributor has legal authority to
enter into this Agreement and legal authority over Contributed code.

Contributor will not allow anyone other than the Contributor to use his or her
username or source repository login to Submit code to Submit to the project.


The "Obvious fix" rule
^^^^^^^^^^^^^^^^^^^^^^

Very small Contributions such as fixing spelling errors, where the content is
small enough to not be intellectual property, can be Submitted by Contributor
without signing this agreement.

For this rule to apply, Contributor should implicitly state the terms *obvious
fix* in the Submission.

Any other work will require the Contribution Agreement to be signed.


What qualifies as an Obvious fix?
"""""""""""""""""""""""""""""""""

An *Obvious fix* is a Submission that does not contain creative work. This terms
may be subjective however, as a rule of thumb changes are obvious fixes if they
do not introduce any new functionality or creative thinking. This may include be
not only the following:

- spelling and grammar fixes;
- changes to white space or formatting;
- moving files from one directory to another with no changes in the source code.


Submission
^^^^^^^^^^

To improve tracking of Contributions, Contributor is asked to *sign-off* any
Submission made.

The *sign-off* is a simple line at the end of the explanation for the
Submission, which certifies that Contributor has legal authority over the
Submission or otherwise have the right to pass it on as an open-source project.

By making a Contribution to this project, Contributor certifies that:

1. Contribution was created in whole or in part by Contributor and Contributor
   has the right to Submit it under the open source license indicated in the
   ``LICENSE.rst`` file; or

2. Contribution is based upon previous work that, to the best of Contributor's
   knowledge, is covered under an appropriate open source license and
   Contributor has the right under that license to Submit that work with
   modifications, whether created in whole or in part by Contributor, under the
   same open source license (unless I am permitted to Submit under a different
   license), as indicated in the file ``LICENSE.rst``; or

3. Contribution was provided directly to Contributor by some other person who
   certified one of the above points and Contributor has not modified it.

4. Contributor understands and agrees that this project and the Contribution are
   public and that a record of the Contribution (including all personal
   information Submitted with it) is maintained indefinitely and may be
   redistributed consistent with this project or the open source license(s)
   involved.

If above points can be certified, Contributor can add the following line within
the Submission::

    Signed-off-by: Full Name <email address>


Licensing exceptions
--------------------

This project can include files from third party projects which license allows to
included within the *none* project but does not fall under the terms stated
above.

Such files are explicitly enclosing the licensing terms they fall under and are
listed in the bellow section for clarity.


List of licensing exceptions
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

- ``CODE_OF_CONDUCT.rst``, `Creative Commons Attribution-ShareAlike 3.0 Unported
  License <https://creativecommons.org/licenses/by-sa/3.0/>`_


List of Contributors
--------------------

The below-signed are contributors to the project named *none*. Each below-signed
contributor has read, understand and agrees to the terms above in the section
within this document entitled as of the date beside his or her full name in the
form::

    - Full Name <email address>, YYYY/MM/DD

Where ``YYYY`` is the year of signature on 4 digits (i.e. 1970), ``MM`` the
month of signature on 2 digits (i.e 01 for January until 12 for December) and
``DD`` the day of signature on 2 digits (i.e. 15 for the 15th day of the month).


Contributors
^^^^^^^^^^^^

- Jimmy Thrasibule <dev@jimmy.lt>, 2020/08/25
